"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Connection = void 0;
const amqp_connection_manager_1 = require("amqp-connection-manager");
const utils_1 = require("./utils");
class Connection {
    #uri;
    #amqpConnectionManager;
    constructor({ uri, host, port, username, password, virtualHost, ...options }) {
        if (!uri) {
            uri = (0, utils_1.combine)({ joinWith: '/' }, (0, utils_1.combine)({ joinWith: '@' }, (0, utils_1.combine)({ joinWith: '' }, 'amqp://', (0, utils_1.combine)({ joinWith: ':' }, username, password)), (0, utils_1.combine)({ joinWith: ':' }, host, port.toString())), virtualHost);
        }
        this.#uri = uri;
        this.#amqpConnectionManager = (0, amqp_connection_manager_1.connect)([uri], options);
    }
    get connection() {
        return this.#amqpConnectionManager;
    }
    get uri() {
        return this.#uri;
    }
    createChannel({ json = true, ...rest } = {}) {
        return this.#amqpConnectionManager.createChannel({
            json,
            ...rest,
        });
    }
    close() {
        return this.#amqpConnectionManager.close();
    }
}
exports.Connection = Connection;
